==> fengoffice_1.7.5.zip: fengoffice/language/es_es/general.php <==
<?php return array(
	'username' => 'Nombre de usuario',
	'email or username' => 'Email o usuario',
	'password' => 'Contraseña',
	'password again' => 'Repita su contraseña',
	'old password' => 'Contraseña anterior',
	'new password' => 'Nueva contraseña',
	'remember me' => 'Recordarme durante 14 días',
	'email address' => 'Dirección de correo electrónico',
	'display name' => 'Nombre visible',
	'overview' => 'Vista general',
	'search' => 'Buscar',
	'search results' => 'Resultados de la búsqueda',
	'account' => 'Cuenta',
	'settings' => 'Configuraciones',
	'index' => 'Índice',
	'view' => 'Ver',
	'edit' => 'Editar',
	'delete' => 'Eliminar',
	'empty trash can' => 'Vaciar la papelera',
	'save' => 'Guardar',
	'update' => 'Actualizar',
	'submit' => 'Enviar',
	'reset' => 'Reiniciar',
	'change' => 'Cambiar',
	'name' => 'Nombre',
	'title' => 'Título',
	'description' => 'Descripción',
	'text' => 'Texto',
	'additional text' => 'Texto adicional',
	'due date' => 'Fecha límite',
	'use due date' => 'Usar fecha límite',
	'use start date' => 'Usar fecha de inicio',
	'assign to' => 'Asignar a',
	'assigned to description' => 'Para seleccionar al dueño de la cuenta de correo electrónico',
	'late' => 'Tarde',
	'upcoming' => 'Próximo',
	'today' => 'Hoy',
	'yesterday' => 'Ayer',
	'tomorrow' => 'Mañana',
	'n/a' => '<acronym title="No Disponible">n/a</acronym>',
	'anyone' => 'Todos',
	'nobody' => 'Nadie',
	'none' => '-- Ninguno --',
	'please select' => '-- Por favor seleccione --',
	'reorder' => 'Reordenar',
	'cancel' => 'Cancelar',
	'size' => 'Tamaño',
	'type' => 'Tipo',
	'status' => 'Estado',
	'options' => 'Opciones',
	'active' => 'Activo',
	'completed' => 'Completado',
	'open task status' => 'Abierta',
	'administrator' => 'Administrador',
	'deleted user' => 'un usuario borrado',
	'error' => 'Error',
	'yes' => 'Sí',
	'no' => 'No',
	'all' => 'Todos',
	'or' => 'O',
	'by' => 'Por',
	'on' => 'El',
	'in' => 'En',
	'people' => 'Gente',
	'dates' => 'Fechas',
	'permission' => 'Permiso',
	'permissions' => 'Permisos',
	'owner' => 'Dueño',
	'instant messengers' => 'Mensaje instántaneo',
	'value' => 'Valor',
	'phone number' => 'Número de teléfono',
	'phone numbers' => 'Números de teléfono',
	'office phone number' => 'Oficina',
	'fax number' => 'Fax',
	'mobile phone number' => 'Número de teléfono móvil',
	'home phone number' => 'Número de teléfono de casa',
	'homepage' => 'Sitio web',
	'address' => 'Dirección',
	'address2' => 'Dirección 2',
	'city' => 'Ciudad',
	'state' => 'Estado',
	'zipcode' => 'Código postal',
	'country' => 'País',
	'contact' => 'Contacto',
	'pagination page' => 'Página:',
	'pagination first' => 'Primera página',
	'pagination previous' => 'Página anterior',
	'pagination next' => 'Siguiente página',
	'pagination last' => 'Última página',
	'pagination current page' => 'Página: {0}',
	'download' => 'Descarga',
	'downloads' => 'Descargass',
	'replace' => 'Reemplazar',
	'expand' => 'Expandir',
	'collapse' => 'Contraer',
	'author' => 'Autor',
	'user title' => 'Cargo',
	'more' => 'Más',
	'order by' => 'Ordenar por',
	'filename' => 'Nombre del archivo',
	'permalink' => 'Enlace permanente (Permalink)',
	'timezone' => 'Zona horaria',
	'upgrade' => 'Mejora',
	'changelog' => 'Cambios',
	'hint' => 'Pista',
	'order' => 'Ordenar',
	'read' => 'Leer',
	'workspace' => 'Area de trabajo',
	'event' => 'Evento',
	'events' => 'Eventos',
	'Event' => 'Evento',
	'Events' => 'Eventos',
	'project calendar' => '{0} calendario',
	'user calendar' => 'Calendario de {0}',
	'month 1' => 'Enero',
	'month 2' => 'Febrero',
	'month 3' => 'Marzo',
	'month 4' => 'Abril',
	'month 5' => 'Mayo',
	'month 6' => 'Junio',
	'month 7' => 'Julio',
	'month 8' => 'Agosto',
	'month 9' => 'Septiembre',
	'month 10' => 'Octubre',
	'month 11' => 'Noviembre',
	'month 12' => 'Diciembre',
	'monday' => 'Lunes',
	'tuesday' => 'Martes',
	'wednesday' => 'Miércoles',
	'thursday' => 'Jueves',
	'friday' => 'Viernes',
	'saturday' => 'Sábado',
	'sunday' => 'Domingo',
	'monday short' => 'Lun',
	'tuesday short' => 'Mar',
	'wednesday short' => 'Mié',
	'thursday short' => 'Jue',
	'friday short' => 'Vie',
	'saturday short' => 'Sáb',
	'sunday short' => 'Dom',
	'1st' => '1er',
	'2nd' => '2do',
	'3rd' => '3er',
	'4th' => '4to',
	'5th' => '5to',
	'copy of' => 'Copia de {0}',
	'task templates' => 'Plantilla de tarea',
	'add task template' => 'Añadir Plantilla de tarea',
	'template' => 'Plantilla',
	'workspaces' => 'Áreas de trabajo',
	'assign to workspace' => 'Asignar a áreas de trabajo',
	'assign' => 'Asignar',
	'assign task template to workspace' => 'Asignar plantilla de tareas \'{0}\' a áreas de trabajo',
	'confirm delete task template' => 'Está seguro que desea eliminar esta plantilla de tarea permanentemente? De hacerlo dejara de estar disponible en todo el sistema.',
	'create contact from user' => 'Crear contacto del usuario',
	'confirm create contact from user' => 'Está seguro de que desea crear un contacto con los datos de este usuario?',
	'create contact from user desc' => 'Al seleccionar sí, se creará un contacto del sistema asociado a este usuario',
	'use previous personal workspace' => 'Usar un Espacio de trabajo ya existente como espacio de trabajo personal para este usuario',
	'use previous personal workspace desc' => 'El espacio personal es donde se colocarán los nuevos objetos del usuario por defecto (cuando "Todos" está seleccionado en el panel de Espacios). Al seleccionar Si deberá determinar que espacio de trabajo utilizar como espacio de trabajo personal para este usuario',
	'select personal workspace' => 'Seleccione un Espacio de Trabajo',
	'create personal workspace' => 'Crear un nuevo Espacio de Trabajo',
	'use an existing workspace' => 'Usar un espacio de trabajo existente',
	'no task templates' => 'No hay plantillas de tareas',
	'go to contact' => 'Ir a datos de contacto',
	'show assigned to' => 'Mostrar asignados a',
	'show by status' => 'Mostrar por estado',
	'show by priority' => 'Mostrar por prioridad',
	'task report' => 'Reporte de tareas',
	'priority' => 'Prioridad',
	'anybody' => 'Todos',
	'read and write' => 'Lectura y Escritura',
	'read only' => 'Sólo lectura',
	'none no bars' => 'Ninguno',
	'apply to all subworkspaces' => 'Aplicar permisos a todas las subáreas',
	'weblinks' => 'Enlaces Web',
	'include subworkspaces' => 'Incluir subáreas',
	'timeslot on object' => 'Tiempo de trabajo en {0}',
	'add work' => 'Añadir trabajo',
	'date format' => 'd/m/Y',
	'date format description' => '(día/mes/año)',
	'confirm move to trash' => 'Está seguro que desea mover el objeto seleccionado a la papelera?',
	'add' => 'Añadir',
	'shared with' => 'Compartido con',
	'remove' => 'Quitar',
	'mime type' => 'Tipo MIME',
	'default' => 'Predeterminado',
	'language' => 'Idioma',
	'before' => 'antes',
	'pages' => 'páginas',
	'repeat by' => 'Repetir según',
	'repeating task' => 'Tarea Repetitiva',
	'this task repeats' => 'Esta tarea se repite',
	'forever' => 'para siempre',
	'n times' => '{0} veces',
	'until x' => 'hasra {0}',
	'n days' => '{0} días',
	'n months' => '{0} meses',
	'n years' => '{0} años',
	'every' => 'cada',
	'generate repetitition' => 'Generar repetición de la tarea',
	'end of task' => 'Fin de Tarea',
	'start of task' => 'Inicio de Tarea',
	'new task repetition generated' => 'Se ha generado una nueva repetición de la tarea',
	'reminders will not apply to repeating events' => 'Aviso: los recordatorios no se aplican a eventos repetitivos',
	'move all to right' => 'Mover todos hacia la derecha',
	'move to right' => 'Mover hacia la derecha',
	'move to left' => 'Mover hacia la izquierda',
	'move all to left' => 'Mover todos hacia la izquierda',
	'move up' => 'Subir',
	'move down' => 'Bajar',
	'this file is included in document' => 'Este documento está incluído en: {0}',
	'minutes ago' => 'Hace {0} minutos',
	'about hours ago' => 'Aprox. hace {0} horas',
	'yesterday at' => 'Ayer a las {0}',
	'day at' => '{0} a las {1}',
	'added by capitalized' => 'Agregado por',
	'in capitalized' => 'En',
	'unique id capitalized' => 'Id. único',
	'system notification email' => 'Esto es una notificación del sistema, no responder a este correo.',
	'modifications tab' => 'Modificaciones',
	'views tab' => 'Vistas',
	'latest activity' => 'Última actividad',
	'view all activity' => 'Ver toda la actividad...',
	'advanced' => 'Avanzado',
	'workspace and tags' => 'Espacio y etiquetas',
	'direct url' => 'URL Directa',
	'the' => 'el',

	'wizard title' => 'Comenzando',	
	'wizard intro' => 'Cree un espacio de trabajo para centralizar y organizar la información de un cliente o proyecto, agregue tareas y comparta información con otras personas.',
  	'wizard intro project' => 'Este asistente te permitirá registrar las personas y sus permisos para el uso del sistema y crear tareas para el proyecto.',
  	'wizard intro customer' => 'Cree un sub-espacio de trabajo para centralizar y organizar la información de un proyecto, agregue tareas y comparta información con otras personas.',

	'wizard new customer title' => 'Agregar un espacio de trabajo para un Cliente.',
	'wizard new customer' => 'En un espacio de trabajo podrás compartir y centralizar toda la información de un Cliente. Para crear o buscar un espacio de trabajo debe utilizar el panel de la izquierda.',
	
	'wizard new project title' => 'Agregar un espacio de trabajo para un Proyecto',
   	'wizard new project' => 'En un espacio de trabajo podrás compartir y centralizar toda la información de un Proyecto. Para crear o buscar un espacio de trabajo debe utilizar el panel de la izquierda.',
  	
	'wizard new customer project title' => 'Agregar un espacio de trabajo para un Proyecto del Cliente',
   	'wizard new customer project' => 'Al estar posicionado sobre el espacio de trabajo de un Cliente, éste actúa como “Espacio Padre” y usted puede crear sub-espacios. Un ejemplo de sub-espacio es un Proyecto del Cliente.<br/> En la opción "Resumen" del menú principal usted podrá ver un resumen de la información más relevante del área de trabajo que ha seleccionado en el panel de la izquierda.',
  	
	'wizard new customer task title' => 'Agregar una tarea para este Cliente',
	'wizard new customer task' => 'Agregue tareas para el área de trabajo Cliente o para cualquiera de sus sub-áreas, por ejemplo un Proyecto.',

   	'wizard new project task title' => 'Agregar tareas para este proyecto',	
  	'wizard new project task' => 'Asigne tareas – registre antes a la persona y sus permisos-, fechas y prioridades. Agregue sub-tareas, hitos, recordatorios, suscriptores, emails, documentos, notas, horas trabajadas, tareas repetitivas y más. Para ver las tareas de un Proyecto, selecciona el Proyecto en el panel de la izquierda y luego haz click en la opción “Tareas”. Selecciona el Cliente y luego Tareas para ver todas sus tareas.',

	'wizard new user title' => 'Invita a otras Personas',
  	'wizard new user' => 'Debes invitar a una persona para asignarle tareas, permitirle que registre un comentario o que pueda ver los avances de un Cliente o Proyecto. Recuerda otorgarle los permisos en el Proyecto, Cliente o espacio de trabajo que corresponda. También puedes invitar otras personas a través de la opción Administración/Nuevos Usuarios ubicada en la parte superior derecha de la pantalla.',
	
  	'wizard close action' => 'Puedes volver a esta Ayuda haciendo doble click en la opción “Resumen” del Menú Principal',		
); 
?>

==> fengoffice_2.0.0.zip: fengoffice/language/es_es/general.php <==
<?php return array(
	'username' => 'Nombre de usuario',
	'email or username' => 'Email o usuario',
	'password' => 'Contraseña',
	'password again' => 'Repita su nueva contraseña',
	'old password' => 'Contraseña anterior',
	'new password' => 'Nueva contraseña',
	'remember me' => 'Recordarme durante 14 días',
	'email address' => 'Email',
	'display name' => 'Nombre visible',
	'overview' => 'Vista general',
	'search' => 'Buscar',
	'search results' => 'Resultados de la búsqueda',
	'account' => 'Cuenta',
	'settings' => 'Configuraciones',
	'index' => 'Índice',
	'view' => 'Ver',
	'edit' => 'Editar',
	'delete' => 'Eliminar',
	'empty trash can' => 'Vaciar la papelera',
	'save' => 'Guardar',
	'update' => 'Actualizar',
	'submit' => 'Enviar',
	'reset' => 'Reiniciar',
	'change' => 'Cambiar',
	'name' => 'Nombre',
	'title' => 'Título',
	'description' => 'Descripción',
	'text' => 'Texto',
	'untitled note' => 'Nota sín titulo',
	'additional text' => 'Texto adicional',
	'due date' => 'Fecha límite',
	'use due date' => 'Usar fecha límite',
	'use start date' => 'Usar fecha de inicio',
	'assign to' => 'Asignar a',
	'assigned to description' => 'Para seleccionar al dueño de la cuenta de correo electrónico',
	'late' => 'Tarde',
	'upcoming' => 'Próximo',
	'today' => 'Hoy',
	'yesterday' => 'Ayer',
	'tomorrow' => 'Mañana',
	'n/a' => '<acronym title="No Disponible">n/a</acronym>',
	'anyone' => 'Todos',
	'nobody' => 'Nadie',
	'none' => '-- Ninguno --',
	'please select' => '-- Por favor seleccione --',
	'reorder' => 'Reordenar',
	'cancel' => 'Cancelar',
	'size' => 'Tamaño',
	'type' => 'Tipo',
	'status' => 'Estado',
	'options' => 'Opciones',
	'active' => 'Activo',
	'completed' => 'Completado',
	'administrator' => 'Administrador',
	'error' => 'Error',
	'yes' => 'Sí',
	'no' => 'No',
	'all' => 'Todos',
	'or' => 'O',
	'by' => 'Por',
	'on' => 'El',
	'in' => 'En',
	'people' => 'Gente',
	'dates' => 'Fechas',
	'permission' => 'Permiso',
	'permissions' => 'Permisos',
	'owner' => 'Dueño',
	'instant messengers' => 'Mensaje instántaneo',
	'value' => 'Valor',
	'phone number' => 'Número de teléfono',
	'phone numbers' => 'Números de teléfono',
	'office phone number' => 'Oficina',
	'fax number' => 'Fax',
	'mobile phone number' => 'Número de teléfono móvil',
	'home phone number' => 'Número de teléfono de casa',
	'homepage' => 'Sitio web',
	'address' => 'Dirección',
	'address2' => 'Dirección 2',
	'city' => 'Ciudad',
	'state' => 'Estado',
	'zipcode' => 'Código postal',
	'country' => 'País',
	'contact' => 'Contacto',
	'person' => 'Persona',
	'pagination page' => 'Página:',
	'pagination first' => 'Primera página',
	'pagination previous' => 'Página anterior',
	'pagination next' => 'Siguiente página',
	'pagination last' => 'Última página',
	'pagination current page' => 'Página: {0}',
	'download' => 'Descarga',
	'downloads' => 'Descargass',
	'replace' => 'Reemplazar',
	'expand' => 'Expandir',
	'collapse' => 'Contraer',
	'author' => 'Autor',
	'user title' => 'Cargo',
	'more' => 'Más',
	'order by' => 'Ordenar por',
	'filename' => 'Nombre del archivo',
	'permalink' => 'Enlace permanente (Permalink)',
	'timezone' => 'Zona horaria',
	'upgrade' => 'Mejora',
	'changelog' => 'Cambios',
	'hint' => 'Pista',
	'order' => 'Ordenar',
	'read' => 'Leer',
	'workspace' => 'Area de trabajo',
	'event' => 'Evento',
	'events' => 'Eventos',
	'Event' => 'Evento',
	'Events' => 'Eventos',
	'project calendar' => '{0} calendario',
	'user calendar' => 'Calendario de {0}',
	'month 1' => 'Enero',
	'month 2' => 'Febrero',
	'month 3' => 'Marzo',
	'month 4' => 'Abril',
	'month 5' => 'Mayo',
	'month 6' => 'Junio',
	'month 7' => 'Julio',
	'month 8' => 'Agosto',
	'month 9' => 'Septiembre',
	'month 10' => 'Octubre',
	'month 11' => 'Noviembre',
	'month 12' => 'Diciembre',
	'monday' => 'Lunes',
	'tuesday' => 'Martes',
	'wednesday' => 'Miércoles',
	'thursday' => 'Jueves',
	'friday' => 'Viernes',
	'saturday' => 'Sábado',
	'sunday' => 'Domingo',
	'monday short' => 'Lun',
	'tuesday short' => 'Mar',
	'wednesday short' => 'Mié',
	'thursday short' => 'Jue',
	'friday short' => 'Vie',
	'saturday short' => 'Sáb',
	'sunday short' => 'Dom',
	'1st' => '1er',
	'2nd' => '2do',
	'3rd' => '3er',
	'4th' => '4to',
	'5th' => '5to',
	'copy of' => 'Copia de {0}',
	'task templates' => 'Plantilla de tarea',
	'add task template' => 'Añadir Plantilla de tarea',
	'template' => 'Plantilla',
	'workspaces' => 'Áreas de trabajo',
	'assign to workspace' => 'Asignar a áreas de trabajo',
	'assign' => 'Asignar',
	'assign task template to workspace' => 'Asignar plantilla de tareas \'{0}\' a áreas de trabajo',
	'confirm delete task template' => 'Está seguro que desea eliminar esta plantilla de tarea permanentemente? De hacerlo dejara de estar disponible en todo el sistema.',
	'create contact from user' => 'Crear contacto con datos del usuario',
	'confirm create contact from user' => 'Está seguro de que desea crear un contacto con los datos de este usuario?',
	'create contact from user desc' => 'Al seleccionar sí, se creará un contacto del sistema asociado a este usuario',
	'use previous personal workspace' => 'Usar un Espacio de trabajo ya existente como espacio de trabajo personal para este usuario',
	'use previous personal workspace desc' => 'El espacio personal es donde se colocarán los nuevos objetos del usuario por defecto (cuando "Todos" está seleccionado en el panel de Espacios). Al seleccionar Si deberá determinar que espacio de trabajo utilizar como espacio de trabajo personal para este usuario',
	'select personal workspace' => 'Seleccione un Espacio de Trabajo',
	'create personal workspace' => 'Crear un nuevo Espacio de Trabajo',
	'use an existing workspace' => 'Usar un espacio de trabajo existente',
	'no task templates' => 'No hay plantillas de tareas',
	'go to contact' => 'Ir a datos de contacto',
	'show assigned to' => 'Mostrar asignados a',
	'show by status' => 'Mostrar por estado',
	'show by priority' => 'Mostrar por prioridad',
	'task report' => 'Reporte de tareas',
	'priority' => 'Prioridad',
	'anybody' => 'Todos',
	'read write and delete' => 'Lectura, Escritura y Borrado',
	'read and write' => 'Lectura y Escritura',
	'read only' => 'Sólo lectura',
	'none no bars' => 'Ninguno',
	'apply to all subworkspaces' => 'Aplicar permisos a todas las subáreas',
	'weblinks' => 'Enlaces Web',
	'include subworkspaces' => 'Incluir subáreas',
	'timeslot on object' => 'Tiempo de trabajo en {0}',
	'add work' => 'Añadir trabajo',
	'date format' => 'd/m/Y',
	'date format description' => '(día/mes/año)',
	'confirm move to trash' => 'Está seguro que desea mover el objeto seleccionado a la papelera?',
	'add' => 'Añadir',
	'shared with' => 'Compartido con',
	'remove' => 'Quitar',
	'mime type' => 'Tipo MIME',
	'default' => 'Predeterminado',
	'language' => 'Idioma',
	'before' => 'antes',
	'pages' => 'páginas',
	'repeat by' => 'Repetir según',
	'repeating task' => 'Tarea Repetitiva',
	'this task repeats' => 'Esta tarea se repite',
	'forever' => 'para siempre',
	'n times' => '{0} veces',
	'until x' => 'hasra {0}',
	'n days' => '{0} días',
	'n months' => '{0} meses',
	'n years' => '{0} años',
	'every' => 'cada',
	'generate repetitition' => 'Generar repetición de la tarea',
	'end of task' => 'Fin de Tarea',
	'start of task' => 'Inicio de Tarea',
	'new task repetition generated' => 'Se ha generado una nueva repetición de la tarea',
	'reminders will not apply to repeating events' => 'Aviso: los recordatorios no se aplican a eventos repetitivos',
	'move all to right' => 'Mover todos hacia la derecha',
	'move to right' => 'Mover hacia la derecha',
	'move to left' => 'Mover hacia la izquierda',
	'move all to left' => 'Mover todos hacia la izquierda',
	'move up' => 'Subir',
	'move down' => 'Bajar',
	'this file is included in document' => 'Este documento está incluido en: {0}',
	'minutes ago' => 'Hace {0} minutos',
	'about hours ago' => 'Aprox. hace {0} horas',
	'yesterday at' => 'Ayer a las {0}',
	'day at' => '{0} a las {1}',
	'added by capitalized' => 'Agregado por',
	'in capitalized' => 'En',
	'unique id capitalized' => 'Id. único',
	'system notification email' => 'Esto es una notificación del sistema, no responder a este correo.',
	'modifications tab' => 'Modificaciones',
	'views tab' => 'Vistas',
	'latest activity' => 'Última actividad',
	'view all activity' => 'Ver toda la actividad...',
	'advanced' => 'Avanzado',
	'workspace and tags' => 'Espacio y etiquetas',
	'direct url' => 'URL Directa',
	'the' => 'el',
	'percent completed' => 'Porcentaje completado',
        'percent completed detail' => 'El porcentaje de avance se calcula en base a la cantidad de horas trabajadas sobre la cantidad de horas estimadas',
	'task percent completed must be greater than 0' => 'El porcentaje completado debe ser mayor que 0.',
	'task percent completed must be lower than 100' => 'El porcentaje completado debe ser menor o igual a 100.',
); ?>
